/************************************************************\
 * Copyright 2017 Lawrence Livermore National Security, LLC
 * (c.f. AUTHORS, NOTICE.LLNS, COPYING)
 *
 * This file is part of the Flux resource manager framework.
 * For details, see https://github.com/flux-framework.
 *
 * SPDX-License-Identifier: LGPL-3.0
\************************************************************/

#ifndef _FLUX_CORE_KVS_COMMIT_H
#define _FLUX_CORE_KVS_COMMIT_H

#ifdef __cplusplus
extern "C" {
#endif

/* FLUX_KVS_TXN_COMPACT will currently consolidate appends to the same
 * key.  For example, an append of "A" to the key "foo" and the append
 * "B" to the key "foo" maybe consolidated into a single append of
 * "AB".
 *
 * Compacting transactions means that certain ordered lists of
 * operations will be illegal to compact and result in an error.  Most
 * notably, if a key has data appended to it, then is overwritten in
 * the same transaction, a compaction of appends is not possible.
 */
enum kvs_commit_flags {
    FLUX_KVS_NO_MERGE = 1, /* disallow commits to be mergeable with others */
    FLUX_KVS_TXN_COMPACT = 2, /* try to combine ops on same key within txn */
};

flux_future_t *flux_kvs_commit (flux_t *h, const char *ns, int flags,
                                flux_kvs_txn_t *txn);

flux_future_t *flux_kvs_fence (flux_t *h, const char *ns, int flags,
                               const char *name, int nprocs,
                               flux_kvs_txn_t *txn);

/* accessors can be used for commit or fence futures */
int flux_kvs_commit_get_treeobj (flux_future_t *f, const char **treeobj);
int flux_kvs_commit_get_sequence (flux_future_t *f, int *rootseq);

#ifdef __cplusplus
}
#endif

#endif /* !_FLUX_CORE_KVS_COMMIT_H */

/*
 * vi:tabstop=4 shiftwidth=4 expandtab
 */
